@@ -1,5 +1,5 @@
 
-package WWW::Search::Scraper::Google;
+package WWW::Search::Scraper::ZIPplus4;
 
 
 #####################################################################
@@ -8,7 +8,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw(trimTags);
 @ISA = qw(WWW::Search::Scraper Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 use WWW::Search::Scraper(qw(2.12 generic_option addURL trimTags));
@@ -23,7 +23,7 @@ my $scraperQuery =
             ,'submitButton' => 'btnG'
             
             # This is the basic URL on which to get the form to build the query.
-            ,'url' => 'http://www.Google.com'
+            ,'url' => 'http://www.usps.com/' #ncsc/lookups/'
 
            # specify defaults, by native field names
            ,'nativeQuery' => 'q'
@@ -44,7 +44,7 @@ my $scraperQuery =
 my $scraperFrame =
        [ 'HTML', 
           [ 
-                  [ 'NEXT', 1, '[^>]>Next<' ], # Google keeps changing their formatting, so watch out!
+                  [ 'NEXT', 1, '[^>]>Next<' ], # ZIPplus4 keeps changing their formatting, so watch out!
                   [ 'COUNT', '[,0-9]+</b> of about <b>([,0-9]+)</b>'] ,
                   [ 'TABLE', '#4' ],
                   [ 'HIT*' ,
@@ -81,7 +81,7 @@ sub testParameters {
                 ,'testNativeQuery' => 'search scraper'
                 ,'expectedOnePage' => 9
                 ,'expectedMultiPage' => 41
-                ,'expectedBogusPage' => 0
+                ,'expectedBogusPage' => 1
            };
 }
 
@@ -116,33 +116,33 @@ __END__
 
 =head1 NAME
 
-WWW::Search::Scraper::Google - class for searching www.Google.com
+WWW::Search::Scraper::ZIPplus4 - class for searching www.ZIPplus4.com
 
 
 =head1 SYNOPSIS
 
     require WWW::Search::Scraper;
-    $search = new WWW::Search::Scraper('Google');
+    $search = new WWW::Search::Scraper('ZIPplus4');
 
 
 =head1 DESCRIPTION
 
-This class is an Google specialization of WWW::Search.
-It handles making and interpreting Google searches
-F<http://www.Google.com>.
+This class is an ZIPplus4 specialization of WWW::Search.
+It handles making and interpreting ZIPplus4 searches
+F<http://www.ZIPplus4.com>.
 
 =head1 INTERESTING
 
-Go to http://www.google.com and search for "search scraper"; as in 
+Go to http://www.ZIPplus4.com and search for "search scraper"; as in 
 
-http://www.google.com/search?q=search+scraper&sourceid=opera&num=0&ie=utf-8&oe=utf-8
+http://www.ZIPplus4.com/search?q=search+scraper&sourceid=opera&num=0&ie=utf-8&oe=utf-8
 
 Interesting FIRST hit !
 
 =head1 AUTHOR and CURRENT VERSION
 
 
-C<WWW::Search::Scraper::Google> is written and maintained
+C<WWW::Search::Scraper::ZIPplus4> is written and maintained
 by Glenn Wood, http://search.cpan.org/search?mode=author&query=GLENNWOOD.
 
 =head1 COPYRIGHT
